%define _disable_ld_no_undefined 1

%bcond_with extracheck
%bcond_with pcre

%define ver	2.49.92
%define date	2018-02-18

Summary:	Common Lisp (ANSI CL) implementation
Name:		clisp
Epoch:		1
Version:	%{ver}
Release:	%mkrel 7
License:	GPLv2
Group:		Development/Other
#Source0:	https://ftp.gnu.org/gnu/clisp/latest/%{name}-%{version}.tar.bz2
Source0:	https://gitlab.com/gnu-clisp/clisp/-/archive/clisp-%{version}%{?date:-%date}/clisp-clisp-%{version}%{?date:-%date}.tar.gz
# https://sourceforge.net/p/clisp/patches/35/
Patch0:		%{name}-db.patch
# https://sourceforge.net/p/clisp/patches/32/
Patch1:		%{name}-format.patch
# The encrypt and setkey functions are no longer available from glibc
Patch2:		%{name}-setkey.patch
# Adapt to changes in pari 2.11.0
Patch3:		%{name}-pari.patch

BuildRequires:	db5.3-devel
BuildRequires:  diffutils
BuildRequires:  ffcall-devel
BuildRequires:  gdbm-devel
BuildRequires:  gettext-devel
BuildRequires:  gtk2-devel
BuildRequires:	imake
BuildRequires:  libfcgi-devel
BuildRequires:	libsigsegv-devel
BuildRequires:	locales-en
#BuildRequires:	pari-devel
BuildRequires:  pkgconfig(dbus-1)
BuildRequires:  pkgconfig(ice)
BuildRequires:  pkgconfig(libglade-2.0)
%if %{with pcre}
BuildRequires:  pkgconfig(libpcre)
%endif
BuildRequires:	pkgconfig(libxcrypt)
BuildRequires:  pkgconfig(ncursesw)
BuildRequires:  pkgconfig(sm)
BuildRequires:  pkgconfig(x11)
BuildRequires:	pkgconfig(xau)
BuildRequires:	pkgconfig(xext)
BuildRequires:	pkgconfig(xpm)
BuildRequires:  pkgconfig(zlib)
BuildRequires:  postgresql-devel
BuildRequires:	pkgconfig(readline)

Provides:       ansi-cl

# clisp contains a copy of gnulib
Provides:	bundled(gnulib)

%description
Common Lisp is a high-level, all-purpose programming language.

CLISP is a Common Lisp implementation by Bruno Haible of Karlsruhe
University and Michael Stoll of Munich University, both in Germany.

It mostly supports Common Lisp as described in the ANSI CL standard.
It runs on microcomputers (DOS, OS/2, Windows NT, Windows 95, Amiga
500-4000, Acorn RISC PC) as well as on Unix workstations (Linux,
SVR4, Sun4, DEC Alpha OSF, HP-UX, NeXTstep, SGI, AIX, Sun3 and others)
and needs only 2 MB of RAM.

It is free software and may be distributed under the terms of GNU GPL,
while it is possible to distribute commercial applications compiled
with CLISP.

The user interface comes in German, English, French and Spanish.
CLISP includes an interpreter, a compiler, a large subset of CLOS,
a foreign language interface and a socket interface.

An X11 interface is available through CLX and Garnet.


%package	devel
Summary:	Development files for CLISP
Group:		Development/Other
Requires:	%{name} = %{epoch}:%{version}-%{release}
Conflicts:	%{name} < 1:2.49.92

%description	devel
Files necessary for linking CLISP.


%prep
%setup -qn clisp-clisp-%{version}%{?date:-%date}
%autopatch -p0

# Change URLs not affected by the --hyperspec argument to configure
sed -i.orig 's|lisp.org/HyperSpec/Body/chap-7.html|lispworks.com/documentation/HyperSpec/Body/07_.htm|' \
    src/clos-package.lisp
touch -r src/clos-package.lisp.orig src/clos-package.lisp
rm -f src/clos-package.lisp.orig
for f in src/_README.*; do
  sed -i.orig 's|lisp.org/HyperSpec/FrontMatter|lispworks.com/documentation/HyperSpec/Front|' $f
  touch -r ${f}.orig $f
  rm -f ${f}.orig
done

# We only link against libraries in system directories, so we need -L dir in
# place of -Wl,-rpath -Wl,dir
cp -p src/build-aux/config.rpath config.rpath.orig
sed -i.orig -e 's/${wl}-rpath ${wl}/-L/g' src/build-aux/config.rpath

# Fix modules that need access to symbols in libgnu.a
sed -i 's/\(${GLLIB_A}\) \(${LIBS}\)/-Wl,--whole-archive \1 -Wl,--no-whole-archive \2/' src/makemake.in

%build
ulimit -s 16384
export LC_ALL=C.UTF-8

# Do not need to specify base modules: i18n, readline, regexp, syscalls.
# The dirkey module currently can only be built on Windows/Cygwin/MinGW.
# The editor module is not in good enough shape to use.
# The matlab, netica, and oracle modules require proprietary code to build.
# The queens module is intended as an example only, not for actual use.
./configure --prefix=%{_prefix} \
	    --libdir=%{_libdir} \
	    --mandir=%{_mandir} \
	    --infodir=%{_infodir} \
	    --docdir=%{_pkgdocdir} \
	    --fsstnd=redhat \
	    --hyperspec=http://www.lispworks.com/documentation/HyperSpec/ \
	    --with-module=asdf \
	    --with-module=berkeley-db \
	    --with-module=bindings/glibc \
	    --with-module=clx/new-clx \
	    --with-module=dbus \
	    --with-module=fastcgi \
	    --with-module=gdbm \
	    --with-module=gtk2 \
%if 0
	    --with-module=libsvm \
	    --with-module=pari \
%endif
%if %{with pcre}
	    --with-module=pcre \
%endif
	    --with-module=postgresql \
	    --with-module=rawsock \
	    --with-module=zlib \
	    --with-libreadline-prefix=$PWD/readline \
	    --with-ffcall \
%if %{with extracheck}
	    --cbcx \
%endif
            build \
	    CFLAGS="%{optflags}" \
	    LDFLAGS="%{ldflags}"

# don't use %%make_build
make -C build

%install
%make_install  -C build
cp -a build/full %{buildroot}%{_libdir}/%{name}-%{version}
rm -f %{buildroot}%{_pkgdocdir}/doc/clisp.{dvi,1,ps}
rm -f %{buildroot}%{_pkgdocdir}/{COPYRIGHT,GNU-GPL}
cp -p doc/mop-spec.pdf %{buildroot}%{_pkgdocdir}/doc
cp -p doc/*.png %{buildroot}%{_pkgdocdir}/doc
cp -p doc/Why-CLISP* %{buildroot}%{_pkgdocdir}/doc
cp -p doc/regexp.html %{buildroot}%{_pkgdocdir}/doc
find %{buildroot}%{_libdir} -name '*.dvi' | xargs rm -f
%find_lang %{name}
%find_lang %{name}low
cat %{name}low.lang >> %{name}.lang

# Put back the original config.rpath, and fix executable bits
cp -p config.rpath.orig %{buildroot}%{_libdir}/%{name}-%{version}/build-aux/config.rpath
chmod a+x \
  %{buildroot}%{_libdir}/%{name}-%{version}/build-aux/config.guess \
  %{buildroot}%{_libdir}/%{name}-%{version}/build-aux/config.sub \
  %{buildroot}%{_libdir}/%{name}-%{version}/build-aux/depcomp \
  %{buildroot}%{_libdir}/%{name}-%{version}/build-aux/install-sh \
# Fix paths in the Makefiles
for mk in $(find %{buildroot}%{_libdir} -name Makefile); do
  sed -e "s,$PWD/modules,%{_libdir}/%{name}-%{version}," \
      -e "s,$PWD/build/clisp,%{_bindir}/clisp," \
      -e "s,$PWD/build/linkkit,%{_libdir}/%{name}-%{version}/linkkit," \
      -i $mk
done
for mk in %{buildroot}%{_libdir}/%{name}-%{version}/{base,full}/makevars; do
  sed -e "s, -I$PWD[^']*,," \
      -e "s,%{_libdir}/lib\([[:alnum:]]*\)\.so,-l\1,g" \
      -i $mk
done

# Install config.h, which is needed in some cases
for dir in %{buildroot}%{_libdir}/%{name}-%{version}/*; do
  cp -p build/$(basename $dir)/config.h $dir || :
done
cp -p build/config.h %{buildroot}%{_libdir}/%{name}-%{version}
cp -p build/clx/new-clx/config.h \
   %{buildroot}%{_libdir}/%{name}-%{version}/clx/new-clx

# Fix permissions
chmod 0755 %{buildroot}%{_bindir}/%{name}
chmod 0755 %{buildroot}%{_libdir}/%{name}-%{version}/full/lisp.run

# Fix broken symlinks in the full set
pushd %{buildroot}%{_libdir}/%{name}-%{version}/full
for obj in bogomips calls gettext readline regexi; do
  rm -f ${obj}.o
  ln -s ../base/${obj}.o ${obj}.o
done
for obj in libgnu libnoreadline lisp; do
  rm -f ${obj}.a
  ln -s ../base/${obj}.a ${obj}.a
done
for obj in fastcgi fastcgi_wrappers; do
  rm -f ${obj}.o
  ln -s ../fastcgi/${obj}.o ${obj}.o
done
rm -f bdb.o
ln -s ../berkeley-db/bdb.o bdb.o
rm -f clx.o
ln -s ../clx/new-clx/clx.o clx.o
rm -f cpcre.o
ln -s ../pcre/cpcre.o cpcre.o
rm -f dbus.o
ln -s ../dbus/dbus.o dbus.o
rm -f gdbm.o
ln -s ../gdbm/gdbm.o gdbm.o
rm -f gtk.o
ln -s ../gtk2/gtk.o gtk.o
#rm -f libsvm.o
#ln -s ../libsvm/libsvm.o libsvm.o
rm -f linux.o
ln -s ../bindings/glibc/linux.o linux.o
rm -f postgresql.o
ln -s ../postgresql/postgresql.o postgresql.o
rm -f rawsock.o
ln -s ../rawsock/rawsock.o rawsock.o
rm -f zlib.o
ln -s ../zlib/zlib.o zlib.o
popd

# Help the debuginfo generator
ln -s ../../src/modules.c build/base/modules.c
ln -s ../../src/modules.c build/full/modules.c

%files -f %{name}.lang
%{_bindir}/clisp
%{_mandir}/*/*
%{_docdir}/clisp
%dir %{_libdir}/%{name}-%{version}
%dir %{_libdir}/%{name}-%{version}/asdf
%{_libdir}/%{name}-%{version}/asdf/asdf.fas
%dir %{_libdir}/%{name}-%{version}/base
%{_libdir}/%{name}-%{version}/base/lispinit.mem
%{_libdir}/%{name}-%{version}/base/lisp.run
%dir %{_libdir}/%{name}-%{version}/bindings
%dir %{_libdir}/%{name}-%{version}/bindings/glibc
%{_libdir}/%{name}-%{version}/bindings/glibc/*.fas
%dir %{_libdir}/%{name}-%{version}/berkeley-db/
%{_libdir}/%{name}-%{version}/berkeley-db/dbi.fas
%dir %{_libdir}/%{name}-%{version}/clx
%dir %{_libdir}/%{name}-%{version}/clx/new-clx
%{_libdir}/%{name}-%{version}/clx/new-clx/*.fas
%{_libdir}/%{name}-%{version}/data
%dir %{_libdir}/%{name}-%{version}/dbus
%{_libdir}/%{name}-%{version}/dbus/*.fas
%dir %{_libdir}/%{name}-%{version}/fastcgi
%{_libdir}/%{name}-%{version}/fastcgi/*.fas
%dir %{_libdir}/%{name}-%{version}/full/
%{_libdir}/%{name}-%{version}/full/lispinit.mem
%{_libdir}/%{name}-%{version}/full/lisp.run
%dir %{_libdir}/%{name}-%{version}/gdbm
%{_libdir}/%{name}-%{version}/gdbm/*.fas
%dir %{_libdir}/%{name}-%{version}/gtk2
%{_libdir}/%{name}-%{version}/gtk2/*.fas
%{_libdir}/%{name}-%{version}/dynmod
%if %{with pcre}
%dir %{_libdir}/%{name}-%{version}/pcre
%{_libdir}/%{name}-%{version}/pcre/*.fas
%endif
%dir %{_libdir}/%{name}-%{version}/postgresql
%{_libdir}/%{name}-%{version}/postgresql/*.fas
%dir %{_libdir}/%{name}-%{version}/rawsock
%{_libdir}/%{name}-%{version}/rawsock/*.fas
%dir %{_libdir}/%{name}-%{version}/zlib
%{_libdir}/%{name}-%{version}/zlib/*.fas
%{_datadir}/emacs/site-lisp/*
%{_datadir}/vim/vimfiles/after/syntax/lisp.vim

%files devel
%{_bindir}/clisp-link
%{_mandir}/man1/clisp-link.1*
%{_libdir}/%{name}-%{version}/asdf/Makefile
%{_libdir}/%{name}-%{version}/asdf/*.lisp
%{_libdir}/%{name}-%{version}/asdf/*.sh
%{_libdir}/%{name}-%{version}/base/*.a
%{_libdir}/%{name}-%{version}/base/*.h
%{_libdir}/%{name}-%{version}/base/*.o
%{_libdir}/%{name}-%{version}/base/makevars
%{_libdir}/%{name}-%{version}/berkeley-db/Makefile
%{_libdir}/%{name}-%{version}/berkeley-db/*.h
%{_libdir}/%{name}-%{version}/berkeley-db/*.lisp
%{_libdir}/%{name}-%{version}/berkeley-db/*.o
%{_libdir}/%{name}-%{version}/berkeley-db/*.sh
%{_libdir}/%{name}-%{version}/bindings/glibc/Makefile
%{_libdir}/%{name}-%{version}/bindings/glibc/*.lisp
%{_libdir}/%{name}-%{version}/bindings/glibc/*.o
%{_libdir}/%{name}-%{version}/bindings/glibc/*.sh
%{_libdir}/%{name}-%{version}/build-aux/
%{_libdir}/%{name}-%{version}/clx/new-clx/demos/
%{_libdir}/%{name}-%{version}/clx/new-clx/README
%{_libdir}/%{name}-%{version}/clx/new-clx/Makefile
%{_libdir}/%{name}-%{version}/clx/new-clx/*.h
%{_libdir}/%{name}-%{version}/clx/new-clx/*.lisp
%{_libdir}/%{name}-%{version}/clx/new-clx/*.o
%{_libdir}/%{name}-%{version}/clx/new-clx/*.sh
%{_libdir}/%{name}-%{version}/config.h
%{_libdir}/%{name}-%{version}/dbus/Makefile
%{_libdir}/%{name}-%{version}/dbus/*.h
%{_libdir}/%{name}-%{version}/dbus/*.lisp
%{_libdir}/%{name}-%{version}/dbus/*.o
%{_libdir}/%{name}-%{version}/dbus/*.sh
%{_libdir}/%{name}-%{version}/fastcgi/README
%{_libdir}/%{name}-%{version}/fastcgi/Makefile
%{_libdir}/%{name}-%{version}/fastcgi/*.h
%{_libdir}/%{name}-%{version}/fastcgi/*.lisp
%{_libdir}/%{name}-%{version}/fastcgi/*.o
%{_libdir}/%{name}-%{version}/fastcgi/*.sh
%{_libdir}/%{name}-%{version}/full/*.a
%{_libdir}/%{name}-%{version}/full/*.h
%{_libdir}/%{name}-%{version}/full/*.o
%{_libdir}/%{name}-%{version}/full/makevars
%{_libdir}/%{name}-%{version}/gdbm/Makefile
%{_libdir}/%{name}-%{version}/gdbm/*.h
%{_libdir}/%{name}-%{version}/gdbm/*.lisp
%{_libdir}/%{name}-%{version}/gdbm/*.o
%{_libdir}/%{name}-%{version}/gdbm/*.sh
%{_libdir}/%{name}-%{version}/gtk2/Makefile
%{_libdir}/%{name}-%{version}/gtk2/*.cfg
%{_libdir}/%{name}-%{version}/gtk2/*.glade
%{_libdir}/%{name}-%{version}/gtk2/*.h
%{_libdir}/%{name}-%{version}/gtk2/*.lisp
%{_libdir}/%{name}-%{version}/gtk2/*.o
%{_libdir}/%{name}-%{version}/gtk2/*.sh
%if 0
%{_libdir}/%{name}-%{version}/libsvm/README
%{_libdir}/%{name}-%{version}/libsvm/Makefile
%{_libdir}/%{name}-%{version}/libsvm/*.h
%{_libdir}/%{name}-%{version}/libsvm/*.lisp
%{_libdir}/%{name}-%{version}/libsvm/*.o
%{_libdir}/%{name}-%{version}/libsvm/*.sh
%endif
%{_libdir}/%{name}-%{version}/linkkit/
%if 0
%{_libdir}/%{name}-%{version}/pari/README
%{_libdir}/%{name}-%{version}/pari/Makefile
%{_libdir}/%{name}-%{version}/pari/*.h
%{_libdir}/%{name}-%{version}/pari/*.lisp
%{_libdir}/%{name}-%{version}/pari/*.o
%{_libdir}/%{name}-%{version}/pari/*.sh
%endif
%if %{with pcre}
%{_libdir}/%{name}-%{version}/pcre/Makefile
%{_libdir}/%{name}-%{version}/pcre/*.h
%{_libdir}/%{name}-%{version}/pcre/*.lisp
%{_libdir}/%{name}-%{version}/pcre/*.o
%{_libdir}/%{name}-%{version}/pcre/*.sh
%endif
%{_libdir}/%{name}-%{version}/postgresql/README
%{_libdir}/%{name}-%{version}/postgresql/Makefile
%{_libdir}/%{name}-%{version}/postgresql/*.h
%{_libdir}/%{name}-%{version}/postgresql/*.lisp
%{_libdir}/%{name}-%{version}/postgresql/*.o
%{_libdir}/%{name}-%{version}/postgresql/*.sh
%{_libdir}/%{name}-%{version}/rawsock/demos/
%{_libdir}/%{name}-%{version}/rawsock/Makefile
%{_libdir}/%{name}-%{version}/rawsock/*.h
%{_libdir}/%{name}-%{version}/rawsock/*.lisp
%{_libdir}/%{name}-%{version}/rawsock/*.o
%{_libdir}/%{name}-%{version}/rawsock/*.sh
%{_libdir}/%{name}-%{version}/zlib/Makefile
%{_libdir}/%{name}-%{version}/zlib/*.h
%{_libdir}/%{name}-%{version}/zlib/*.lisp
%{_libdir}/%{name}-%{version}/zlib/*.o
%{_libdir}/%{name}-%{version}/zlib/*.sh
%{_datadir}/aclocal/clisp.m4


%changelog
* Sun Apr 16 2023 daviddavid <daviddavid> 1:2.49.92-7.mga9
+ Revision: 1953164
- disable old pcre support in Mageia 9 (mga#31791)

* Thu Jan 12 2023 daviddavid <daviddavid> 1:2.49.92-6.mga9
+ Revision: 1932545
- rebuild for new libunistring 1.1

* Wed Mar 30 2022 umeabot <umeabot> 1:2.49.92-5.mga9
+ Revision: 1835271
- Mageia 9 Mass Rebuild

* Tue Feb 18 2020 umeabot <umeabot> 1:2.49.92-4.mga8
+ Revision: 1542090
- Mageia 8 Mass Rebuild

* Sat Jan 04 2020 luigiwalser <luigiwalser> 1:2.49.92-3.mga8
+ Revision: 1475939
- rebuild for readline

* Sat Sep 22 2018 umeabot <umeabot> 1:2.49.92-2.mga7
+ Revision: 1296584
- Mageia 7 Mass Rebuild

* Sat Aug 18 2018 wally <wally> 1:2.49.92-1.mga7
+ Revision: 1252532
- new version 2.49.92
- sync patches and .spec with Fedora
+ luigiwalser <luigiwalser>
- rebuild for gdbm

* Sun Jan 21 2018 wally <wally> 1:2.49-18.mga7
+ Revision: 1195531
- add patch from upstream to fix build with new readline
- rebuild for new readline

* Sat Jul 01 2017 akien <akien> 1:2.49-17.mga6
+ Revision: 1108903
- Rebuild for libffcall

* Sun Mar 12 2017 neoclust <neoclust> 1:2.49-16.mga6
+ Revision: 1092132
- Rebuild for armv7

* Thu May 12 2016 tv <tv> 1:2.49-15.mga6
+ Revision: 1014149
- use std build macros; prevent commented out macros to break build

* Sat Feb 13 2016 umeabot <umeabot> 1:2.49-14.mga6
+ Revision: 959729
- Mageia 6 Mass Rebuild

* Thu Feb 11 2016 pterjan <pterjan> 1:2.49-13.mga6
+ Revision: 955981
- Add some patches from fedora, especially one for gcc5
+ umeabot <umeabot>
- Mageia 6 Mass Rebuild

* Tue Nov 25 2014 cjw <cjw> 1:2.49-11.mga5
+ Revision: 799005
- rebuild against postgresql9.4

* Wed Oct 15 2014 umeabot <umeabot> 1:2.49-10.mga5
+ Revision: 745103
- Second Mageia 5 Mass Rebuild

* Thu Sep 18 2014 umeabot <umeabot> 1:2.49-9.mga5
+ Revision: 693622
- Rebuild to fix library dependencies

* Tue Sep 16 2014 umeabot <umeabot> 1:2.49-8.mga5
+ Revision: 678428
- Mageia 5 Mass Rebuild

* Sat Oct 19 2013 umeabot <umeabot> 1:2.49-7.mga4
+ Revision: 526005
- Mageia 4 Mass Rebuild

* Sun Jun 02 2013 kamil <kamil> 1:2.49-6.mga4
+ Revision: 435475
- rebuild for Mageia4

* Fri Jan 11 2013 dmorgan <dmorgan> 1:2.49-5.mga3
+ Revision: 348735
- Use a more complete P1 to fix build ( from fedora )
+ umeabot <umeabot>
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Sun Dec 02 2012 kamil <kamil> 1:2.49-4.mga3
+ Revision: 325088
- add pkgconfig(ncursesw) as BR
- add clisp-2.49-mga-fix-importing-ipc-headers.patch to fix build
- clean .spec a bit
+ fwang <fwang>
- add fedora patch to build with gcc 4.7

* Tue Dec 06 2011 fwang <fwang> 1:2.49-4.mga2
+ Revision: 177155
- rebuild for new gdbm

* Wed Sep 14 2011 fwang <fwang> 1:2.49-3.mga2
+ Revision: 143186
- add back libdir
- cleanup br

* Tue Mar 01 2011 dmorgan <dmorgan> 1:2.49-2.mga1
+ Revision: 62112
- Build with readline

* Tue Mar 01 2011 dmorgan <dmorgan> 1:2.49-1.mga1
+ Revision: 62091
- Fix build
- imported package clisp


* Fri Aug 06 2010 Paulo Andrade <pcpa@mandriva.com.br> 1:2.49-1mdv2011.0
+ Revision: 567191
- Update to version 2.49

* Wed Aug 19 2009 Paulo Andrade <pcpa@mandriva.com.br> 1:2.48-2mdv2010.0
+ Revision: 418280
- Make the -I option completely ignore readline
  # This is an at least "somewhat" elegant version of an alternate ugly hack
  # required to make sagemath python-pexpect interface work correctly with
  # clisp

* Wed Jul 29 2009 Frederik Himpe <fhimpe@mandriva.org> 1:2.48-1mdv2010.0
+ Revision: 404036
- Update to new version 2.48
- Sync configure options and BuildRequires with Fedora (more
  modules are available now)

* Sat Feb 28 2009 Guillaume Rousse <guillomovitch@mandriva.org> 1:2.47-2mdv2009.1
+ Revision: 346030
- rebuild against new readline

* Tue Nov 11 2008 Frederik Himpe <fhimpe@mandriva.org> 1:2.47-1mdv2009.1
+ Revision: 302178
- Update to new version 2.47
- Remove patch fixing postgresql detection, integrated upstream
- Specifically buildrequire version 4.6 of berkeleydb, it does not
  build with db 4.7

* Wed Aug 13 2008 Frederik Himpe <fhimpe@mandriva.org> 1:2.46-1mdv2009.0
+ Revision: 271576
- Update to new version 2.46

* Thu Aug 07 2008 Thierry Vignaud <tv@mandriva.org> 1:2.45-2mdv2009.0
+ Revision: 266536
- rebuild early 2009.0 package (before pixel changes)

* Tue Jun 10 2008 Frederik Himpe <fhimpe@mandriva.org> 1:2.45-1mdv2009.0
+ Revision: 217754
- New version 2.45
- Remove postgresql patch, it is included upstream. Replace it by new pgsql
  patch because upstream configure script has an error finding the headers
- Remove topdir patch: install it in versioned lib directory, like upstream,
  Fedora and Debian are doing
- Needs bigger stack size to succeed in building
- Small Adaptatations to make it build in directory named build
- Build gtk2 module

* Tue Feb 26 2008 Frederik Himpe <fhimpe@mandriva.org> 1:2.44.1-1mdv2008.1
+ Revision: 175504
- New upstream bugfix release

* Wed Feb 13 2008 Frederik Himpe <fhimpe@mandriva.org> 1:2.44-1mdv2008.1
+ Revision: 167118
- New upstream release
- Add libffcall-devel BuildRequires

* Mon Jan 07 2008 Pascal Terjan <pterjan@mandriva.org> 1:2.43-2mdv2008.1
+ Revision: 146277
- Make the -devel installable

* Mon Dec 31 2007 Oden Eriksson <oeriksson@mandriva.com> 1:2.43-1mdv2008.1
+ Revision: 139851
- 2.43

* Thu Dec 27 2007 Oden Eriksson <oeriksson@mandriva.com> 1:2.41a-2mdv2008.1
+ Revision: 138227
- build against db4.2-devel for now
- rebuilt against bdb 4.6.x libs

  + Thierry Vignaud <tv@mandriva.org>
    - kill re-definition of %%buildroot on Pixel's request

* Thu May 31 2007 Per Øyvind Karlsen <peroyvind@mandriva.org> 1:2.41a-1mdv2008.0
+ Revision: 33431
- fix buildrequires
- remove icon
- 2.41a
- add url for source
- update to 2.41 (with help from Frederik Himpe)
- fix detection of postgresql headers (P0 from Frederik)
- Import clisp



* Mon Sep 18 2006 Gwenole Beauchesne <gbeauchesne@mandriva.com> 1:2.38-2mdv2007.0
- Rebuild

* Sat May 20 2006 Per Øyvind Karlsen <pkarlsen@mandriva.com> 2.38-1mdk
- 2.38
- sort out some build issues with flags etc
- build with dynamic modules support
- build against libsigsegv
- lib64 fix
- fix buildrequires
- %%mkrel
- move check to new %%check stage

* Sat Dec 31 2005 Mandriva Linux Team <http://www.mandrivaexpert.com/> 2.33.2-3mdk
- Rebuild

* Thu Jan 20 2005 Per Øyvind Karlsen <peroyvind@linux-mandrake.com> 2.33.2-2mdk
- rebuild for new readline

* Sat Jun 05 2004 Per ?yvind Karlsen <peroyvind@linux-mandrake.com> 2.33.2-1mdk
- 2.33.2
- drop P0

* Sat Apr 17 2004 Per Øyvind Karlsen <peroyvind@linux-mandrake.com> 2.33-2mdk
- fix buildrequires

* Fri Apr 02 2004 Per Øyvind Karlsen <peroyvind@linux-mandrake.com> 2.33-1mdk
- 2.33
- clean docs
- update P0 from debian
- minor fixes
- disable parallell build

* Mon Jun 23 2003 Per Øyvind Karlsen <peroyvind@sintrax.net> 2.30-2mdk
- fix prefix etc. (from Mark Draheim <rickscafe.casablanca@gmx.net>)
- fix %%files list

* Tue Jun 17 2003 Per Øyvind Karlsen <peroyvind@sintrax.net> 2.30-1mdk
- 2.30
- cleanups
- P0 from debian, dropped alpha patch
- alot of spec file fixes

* Tue Jul 17 2001 Daouda LO <daouda@mandrakesoft.com> 2.27-1mdk
- release 2.27
  o The default extension of Lisp source files for CLISP is now ".lisp"
    instead of ".lsp". When both "foo.lisp" and "foo.lsp" exist, 
    (LOAD "foo") will load "foo.lisp".

  o Changed bytecode format. All .fas files generated by previous CLISP
     versions  are invalid and must be recompiled.
  o More Ansi CL compliances  
  o See more of the changelog: http://sourceforge.net/forum/forum.php?forum_id=72006 

- update URL.  
- new versioning scheme.
- merge ppc build.
- s|config.lsp|config.lisp| in ppc build.

* Wed Apr 25 2001 Geoffrey Lee <snailtalk@mandrakesoft.com> 2000.03.06-4mdk
- Make it build on the Alpha platform.
- Quiet output when uncompressing the source because it is really too annoying
  to watch.

* Sun Nov 05 2000 David BAUDENS <baudens@mandrakesoft.com> 2000.03.06-3mdk
- Rewrite spec following Clisp Install documentation to be able to build this
  package on all archs
- Have an intelligent description

* Sun Jul 23 2000 Pixel <pixel@mandrakesoft.com> 2000.03.06-2mdk
- *much* cleanup, macorizaiton, BM

* Mon Apr  3 2000 Adam Lebsack <adam@mandrakesoft.com> 2000.03.06-1mdk
- Update to 2000.03.06

* Tue Feb 22 2000 Stefan van der Eijk <s.vandereijk@chello.nl>
- rewrote most of .spec file
- updated to 1999.07.22
